@@ -3,8 +3,6 @@ import typing as t
 
 from pydantic import BaseModel
 
-from taktile_types.enums.instance import InstanceClass, InstanceSize
-
 
 class DeploymentMetadata(BaseModel):
     """
@@ -35,18 +33,10 @@ class DeploymentSpec(BaseModel):
         URI of repository on github
     principal: str
         user or organization which own the repo
-    rest_instance_size: Optional[InstanceSize]
-        enumeration of size
-    rest_instance_type: Optional[InstanceType]
-        enumeration of type
     rest_cpu_request: Optional[str]
         kubernetes-parsable cpu request
     rest_memory_request: Optiona[str]
         kubernetes-parsable memory request
-    arrow_instance_size: Optional[InstanceSize]
-        enumeration of size
-    arrow_instance_type: Optional[InstanceType]
-        enumeration of type
     arrow_cpu_request: Optional[str]
         kubernetes-parsable cpu request
     arrow_memory_request: Optiona[str]
@@ -80,14 +70,10 @@ class DeploymentSpec(BaseModel):
 
     principal: str
 
-    rest_instance_size: t.Optional[InstanceSize]
-    rest_instance_type: t.Optional[InstanceClass]
-    rest_cpu_request: t.Optional[str]
     rest_memory_request: t.Optional[str]
     rest_gpu_request: t.Optional[str]
+    rest_cpu_request: t.Optional[str]
 
-    arrow_instance_size: t.Optional[InstanceSize]
-    arrow_instance_type: t.Optional[InstanceClass]
     arrow_cpu_request: t.Optional[str]
     arrow_memory_request: t.Optional[str]
     arrow_gpu_request: t.Optional[str]
